@@ -1,5 +1,4 @@
 """HTTP Client using pyCurl."""
-from __future__ import absolute_import, unicode_literals
 
 from collections import deque
 from functools import partial
@@ -8,7 +7,6 @@ from time import time
 
 from kombu.asynchronous.hub import READ, WRITE, get_event_loop
 from kombu.exceptions import HttpError
-from kombu.five import bytes_if_py2, items
 from kombu.utils.encoding import bytes_to_str
 
 from .base import BaseClient
@@ -29,7 +27,7 @@ else:
 
 __all__ = ('CurlClient',)
 
-DEFAULT_USER_AGENT = bytes_if_py2('Mozilla/5.0 (compatible; pycurl)')
+DEFAULT_USER_AGENT = 'Mozilla/5.0 (compatible; pycurl)'
 EXTRA_METHODS = frozenset(['DELETE', 'OPTIONS', 'PATCH'])
 
 
@@ -42,7 +40,7 @@ class CurlClient(BaseClient):
         if pycurl is None:
             raise ImportError('The curl client requires the pycurl library.')
         hub = hub or get_event_loop()
-        super(CurlClient, self).__init__(hub)
+        super().__init__(hub)
         self.max_clients = max_clients
 
         self._multi = pycurl.CurlMulti()
@@ -203,7 +201,7 @@ class CurlClient(BaseClient):
 
         setopt(
             _pycurl.HTTPHEADER,
-            ['{0}: {1}'.format(*h) for h in items(request.headers)],
+            ['{}: {}'.format(*h) for h in request.headers.items()],
         )
 
         setopt(
@@ -231,7 +229,7 @@ class CurlClient(BaseClient):
             setopt(_pycurl.PROXY, request.proxy_host)
             setopt(_pycurl.PROXYPORT, request.proxy_port)
             if request.proxy_username:
-                setopt(_pycurl.PROXYUSERPWD, '{0}:{1}'.format(
+                setopt(_pycurl.PROXYUSERPWD, '{}:{}'.format(
                     request.proxy_username, request.proxy_password or ''))
         else:
             setopt(_pycurl.PROXY, '')
@@ -276,7 +274,7 @@ class CurlClient(BaseClient):
                 'digest': _pycurl.HTTPAUTH_DIGEST
             }[request.auth_mode or 'basic']
             setopt(_pycurl.HTTPAUTH, auth_mode)
-            userpwd = '{0}:{1}'.format(
+            userpwd = '{}:{}'.format(
                 request.auth_username, request.auth_password or '',
             )
             setopt(_pycurl.USERPWD, userpwd)
