@@ -1,9 +1,7 @@
 """Client (Connection)."""
-from __future__ import absolute_import, unicode_literals
 
 import os
 import socket
-import sys
 
 from collections import OrderedDict
 from contextlib import contextmanager
@@ -22,9 +20,6 @@ except ImportError:  # pragma: no cover
 # (Issue #112)
 from kombu import exceptions
 
-from .five import (
-    bytes_if_py2, python_2_unicode_compatible, reraise, string_t, text_t,
-)
 from .log import get_logger
 from .resource import Resource
 from .transport import get_transport_cls, supports_librabbitmq
@@ -53,8 +48,7 @@ _log_connection = os.environ.get('KOMBU_LOG_CONNECTION', False)
 _log_channel = os.environ.get('KOMBU_LOG_CHANNEL', False)
 
 
-@python_2_unicode_compatible
-class Connection(object):
+class Connection:
     """A connection to the broker.
 
     Example:
@@ -170,7 +164,7 @@ class Connection(object):
             'login_method': login_method, 'heartbeat': heartbeat
         }
 
-        if hostname and not isinstance(hostname, string_t):
+        if hostname and not isinstance(hostname, str):
             alt.extend(hostname)
             hostname = alt[0]
             params.update(hostname=hostname)
@@ -274,7 +268,7 @@ class Connection(object):
     def _debug(self, msg, *args, **kwargs):
         if self._logger:  # pragma: no cover
             fmt = '[Kombu connection:{id:#x}] {msg}'
-            logger.debug(fmt.format(id=id(self), msg=text_t(msg)),
+            logger.debug(fmt.format(id=id(self), msg=str(msg)),
                          *args, **kwargs)
 
     def connect(self):
@@ -455,11 +449,9 @@ class Connection(object):
         except (ConnectionError, ChannelError):
             raise
         except self.recoverable_connection_errors as exc:
-            reraise(ConnectionError, ConnectionError(text_t(exc)),
-                    sys.exc_info()[2])
+            raise ConnectionError(str(exc)) from exc
         except self.recoverable_channel_errors as exc:
-            reraise(ChannelError, ChannelError(text_t(exc)),
-                    sys.exc_info()[2])
+            raise ChannelError(str(exc)) from exc
 
     @contextmanager
     def _dummy_context(self):
@@ -564,7 +556,7 @@ class Connection(object):
                         self._debug('ensure channel error: %r',
                                     exc, exc_info=1)
                         errback and errback(exc, 0)
-        _ensured.__name__ = bytes_if_py2('{0}(ensured)'.format(fun.__name__))
+        _ensured.__name__ = f'{fun.__name__}(ensured)'
         _ensured.__doc__ = fun.__doc__
         _ensured.__module__ = fun.__module__
         return _ensured
@@ -592,7 +584,7 @@ class Connection(object):
         """
         channels = [channel]
 
-        class Revival(object):
+        class Revival:
             __name__ = getattr(fun, '__name__', None)
             __module__ = getattr(fun, '__module__', None)
             __doc__ = getattr(fun, '__doc__', None)
@@ -617,7 +609,7 @@ class Connection(object):
     def get_transport_cls(self):
         """Get the currently used transport class."""
         transport_cls = self.transport_cls
-        if not transport_cls or isinstance(transport_cls, string_t):
+        if not transport_cls or isinstance(transport_cls, str):
             transport_cls = get_transport_cls(transport_cls)
         return transport_cls
 
@@ -637,7 +629,7 @@ class Connection(object):
 
         hostname = self.hostname or D.get('hostname')
         if self.uri_prefix:
-            hostname = '%s+%s' % (self.uri_prefix, hostname)
+            hostname = f'{self.uri_prefix}+{hostname}'
 
         info = (
             ('hostname', hostname),
@@ -675,12 +667,12 @@ class Connection(object):
         if self.transport.can_parse_url:
             connection_as_uri = self.hostname
             if self.uri_prefix:
-                connection_as_uri = '%s+%s' % (self.uri_prefix, hostname)
+                connection_as_uri = f'{self.uri_prefix}+{hostname}'
             if not include_password:
                 connection_as_uri = maybe_sanitize_url(connection_as_uri)
             return connection_as_uri
         if self.uri_prefix:
-            connection_as_uri = '%s+%s' % (self.uri_prefix, hostname)
+            connection_as_uri = f'{self.uri_prefix}+{hostname}'
             if not include_password:
                 connection_as_uri = maybe_sanitize_url(connection_as_uri)
             return connection_as_uri
@@ -814,7 +806,7 @@ class Connection(object):
         return exchange_type in self.transport.implements.exchange_type
 
     def __repr__(self):
-        return '<Connection: {0} at {1:#x}>'.format(self.as_uri(), id(self))
+        return '<Connection: {} at {:#x}>'.format(self.as_uri(), id(self))
 
     def __copy__(self):
         return self.clone()
@@ -965,6 +957,8 @@ class Connection(object):
     @property
     def is_evented(self):
         return self.transport.implements.asynchronous
+
+
 BrokerConnection = Connection  # noqa: E305
 
 
@@ -976,7 +970,7 @@ class ConnectionPool(Resource):
 
     def __init__(self, connection, limit=None, **kwargs):
         self.connection = connection
-        super(ConnectionPool, self).__init__(limit=limit)
+        super().__init__(limit=limit)
 
     def new(self):
         return self.connection.clone()
@@ -1019,7 +1013,7 @@ class ChannelPool(Resource):
 
     def __init__(self, connection, limit=None, **kwargs):
         self.connection = connection
-        super(ChannelPool, self).__init__(limit=limit)
+        super().__init__(limit=limit)
 
     def new(self):
         return lazy(self.connection.channel)
