@@ -1,13 +1,11 @@
-from __future__ import absolute_import, unicode_literals
-
 from .base import (
     Base64, NotEquivalentError, UndeliverableWarning, BrokerState,
     QoS, Message, AbstractChannel, Channel, Management, Transport,
     Empty, binding_key_t, queue_binding_t,
 )
 
-__all__ = [
+__all__ = (
     'Base64', 'NotEquivalentError', 'UndeliverableWarning', 'BrokerState',
     'QoS', 'Message', 'AbstractChannel', 'Channel', 'Management', 'Transport',
     'Empty', 'binding_key_t', 'queue_binding_t',
-]
+)
